@@ -19,25 +19,35 @@ package org.apache.maven.shared.utils;
  * under the License.
  */
 
+import java.io.File;
 import java.io.FileInputStream;
 import java.io.IOException;
+import java.io.InputStream;
 import java.util.Properties;
-import org.apache.maven.shared.utils.io.IOUtil;
 
 import javax.annotation.Nonnull;
 import javax.annotation.Nullable;
 
+import org.apache.maven.shared.utils.io.IOUtil;
+
 /**
  * 
  */
 public class PropertyUtils
 {
 
+    /**
+     * The constructor.
+     */
     public PropertyUtils()
     {
         // should throw new IllegalAccessError( "Utility class" );
     }
 
+    /**
+     * @param url The URL which should be used to load the properties.
+     * @return The loaded properties.
+     */
     public static java.util.Properties loadProperties( @Nonnull java.net.URL url )
     {
         try
@@ -51,7 +61,11 @@ public class PropertyUtils
         return null;
     }
 
-    public static java.util.Properties loadProperties( @Nonnull java.io.File file )
+    /**
+     * @param file The file from which the properties will be loaded.
+     * @return The loaded properties.
+     */
+    public static Properties loadProperties( @Nonnull File file )
     {
         try
         {
@@ -64,7 +78,11 @@ public class PropertyUtils
         return null;
     }
 
-    public static java.util.Properties loadProperties( @Nullable java.io.InputStream is )
+    /**
+     * @param is {@link InputStream}
+     * @return The loaded properties.
+     */
+    public static Properties loadProperties( @Nullable InputStream is )
     {
         try
         {
