@@ -83,10 +83,13 @@ import java.util.Random;
  * @author <a href="mailto:Christoph.Reck@dlr.de">Christoph.Reck</a>
  * @author <a href="mailto:peter@apache.org">Peter Donald</a>
  * @author <a href="mailto:jefft@apache.org">Jeff Turner</a>
- * @version $Id: FileUtils.java 1670518 2015-03-31 23:38:42Z hboutemy $
+ * @version $Id: FileUtils.java 1706704 2015-10-04 17:35:19Z khmarbaise $
  */
 public class FileUtils
 {
+    /**
+     * protected constructor.
+     */
     protected FileUtils()
     {
         // This is a utility class.  Normally dont instantiate
@@ -304,7 +307,7 @@ public class FileUtils
      * @param file the file path
      * @return the file content lines as String[] using the systems default encoding.
      * An empty List if the file didn't exist.
-     * @throws IOException
+     * @throws IOException in case of failure.
      */
     @Nonnull public static String[] fileReadArray( @Nonnull File file )
         throws IOException
@@ -657,7 +660,7 @@ public class FileUtils
      * @return The equivalent <code>File</code> object, or <code>null</code> if the URL's protocol
      * is not <code>file</code>
      */
-    public @Nullable static File toFile( final @Nullable URL url )
+    @Nullable public static File toFile( @Nullable final URL url )
     {
         if ( url == null || !url.getProtocol().equalsIgnoreCase( "file" ) )
         {
@@ -692,9 +695,7 @@ public class FileUtils
 
         for ( int i = 0; i < urls.length; i++ )
         {
-            // Although this method is deprecated, it is still the most solid way to translate a File to URL
-            //noinspection deprecation
-            urls[i] = files[i].toURL();
+            urls[i] = files[i].toURI().toURL();
         }
 
         return urls;
@@ -942,7 +943,7 @@ public class FileUtils
      *                     <li>an IO error occurs during copying</li>
      *                     </ul>
      */
-    private static void copyStreamToFile( @Nonnull final @WillClose InputStream source,
+    private static void copyStreamToFile( @Nonnull @WillClose final InputStream source,
                                           @Nonnull final File destination )
         throws IOException
     {
@@ -991,7 +992,7 @@ public class FileUtils
      * @param path the path to normalize
      * @return the normalized String, or <code>null</code> if too many ..'s.
      */
-    public static @Nonnull String normalize( @Nonnull final String path )
+    @Nonnull public static String normalize( @Nonnull final String path )
     {
         String normalized = path;
         // Resolve occurrences of "//" in the normalized path
@@ -1046,7 +1047,7 @@ public class FileUtils
      * @param filename Absolute or relative file path to resolve.
      * @return The canonical <code>File</code> of <code>filename</code>.
      */
-    public static @Nonnull File resolveFile( final File baseFile, @Nonnull String filename )
+    @Nonnull public static File resolveFile( final File baseFile, @Nonnull String filename )
     {
         String filenm = filename;
         if ( '/' != File.separatorChar )
@@ -1181,6 +1182,10 @@ public class FileUtils
         }
     }
 
+    /**
+     * @param file The file.
+     * @return true / false
+     */
     public static boolean deleteLegacyStyle( @Nonnull File file )
     {
         if ( Java7Support.isAtLeastJava7() )
@@ -1430,7 +1435,7 @@ public class FileUtils
      * @param includes  the includes pattern, comma separated
      * @param excludes  the excludes pattern, comma separated
      * @return a list of File objects
-     * @throws IOException
+     * @throws IOException in case of failure.
      * @see #getFileNames(File, String, String, boolean)
      */
     @Nonnull
@@ -1448,7 +1453,7 @@ public class FileUtils
      * @param excludes       the excludes pattern, comma separated
      * @param includeBasedir true to include the base dir in each file
      * @return a list of File objects
-     * @throws IOException
+     * @throws IOException in case of failure.
      * @see #getFileNames(File, String, String, boolean)
      */
     @Nonnull
@@ -1477,7 +1482,7 @@ public class FileUtils
      * @param excludes       the excludes pattern, comma separated
      * @param includeBasedir true to include the base dir in each String of file
      * @return a list of files as String
-     * @throws IOException
+     * @throws IOException in case of failure.
      */
     @Nonnull public static List<String> getFileNames( @Nonnull File directory, @Nullable String includes,
                                                       @Nullable String excludes, boolean includeBasedir )
@@ -1514,7 +1519,7 @@ public class FileUtils
      * @param excludes       the excludes pattern, comma separated
      * @param includeBasedir true to include the base dir in each String of file
      * @return a list of directories as String
-     * @throws IOException
+     * @throws IOException in case of failure.
      */
     @Nonnull public static List<String> getDirectoryNames( @Nonnull File directory, @Nullable String includes,
                                                            @Nullable String excludes, boolean includeBasedir )
@@ -1532,7 +1537,7 @@ public class FileUtils
      * @param includeBasedir  true to include the base dir in each String of file
      * @param isCaseSensitive true if case sensitive
      * @return a list of directories as String
-     * @throws IOException
+     * @throws IOException in case of failure.
      */
     @Nonnull public static List<String> getDirectoryNames( @Nonnull File directory, @Nullable String includes,
                                                            @Nullable String excludes, boolean includeBasedir,
@@ -1862,10 +1867,15 @@ public class FileUtils
     }
 
     /**
-     * 
+     * Wrapper class for Filter.
+     *
      */
     public abstract static class FilterWrapper
     {
+        /**
+         * @param fileReader {@link Reader}
+         * @return The Reader instance.
+         */
         public abstract Reader getReader( Reader fileReader );
     }
 
@@ -2012,9 +2022,11 @@ public class FileUtils
      * </p>
      *
      * @param file the file to check
+     * @throws IOException in case of failure.
+     * @return true if symbolic link false otherwise.
      *
      */
-    public static boolean isSymbolicLink( final @Nonnull File file )
+    public static boolean isSymbolicLink( @Nonnull final File file )
         throws IOException
     {
         if ( Java7Support.isAtLeastJava7() )
@@ -2031,8 +2043,9 @@ public class FileUtils
      * @return true if and only if we reliably can say this is a symlink. This will
      *         always return false for java versions prior to 1.7.
      *
+     * @throws IOException in case of failure.
      */
-    public static boolean isSymbolicLinkForSure( final @Nonnull File file )
+    public static boolean isSymbolicLinkForSure( @Nonnull final File file )
         throws IOException
     {
         return Java7Support.isAtLeastJava7() && Java7Support.isSymLink( file );
@@ -2056,7 +2069,7 @@ public class FileUtils
      * @return true if the file is a symbolic link or if we're on some crappy os.
      *         false if the file is not a symlink or we're not able to detect it.
      */
-    static boolean isSymbolicLinkLegacy( final @Nonnull File file )
+    static boolean isSymbolicLinkLegacy( @Nonnull final File file )
         throws IOException
     {
         final File canonical = new File( file.getCanonicalPath() );
