@@ -549,6 +549,28 @@ public class StringUtilsTest
                 , is( 2 ) );
     }
 
+    @Test
+    public void testEndsWithIgnoreCase()
+    {
+        assertThat( StringUtils.endsWithIgnoreCase( null, null )
+                , is( false ) );
+
+        assertThat( StringUtils.endsWithIgnoreCase( null, "string" )
+                , is( false ) );
+
+        assertThat( StringUtils.endsWithIgnoreCase( "string", null )
+                , is( false ) );
+
+        assertThat( StringUtils.endsWithIgnoreCase( "string", "ing" )
+                , is( true ) );
+
+        assertThat( StringUtils.endsWithIgnoreCase( "string", "a string" )
+                , is( false ) );
+
+        assertThat( StringUtils.endsWithIgnoreCase( "string", "str" )
+                , is( false ) );
+    }
+
     @Test
     public void testEquals()
     {
@@ -2063,5 +2085,4 @@ public class StringUtilsTest
 
     }
 
-
 }
